[java-opensaml COMMIT] in /trunk/opensaml-profile-api/src: main/java/org/opensaml/profile/context/ProfileRequestConte...

noreply at shibboleth.net noreply at shibboleth.net
Mon Jun 2 12:57:28 EDT 2014


Author: scantor
Date: Mon Jun  2 12:57:28 2014
New Revision: 3907

URL: http://svn.shibboleth.net/view/java-opensaml?rev=3907&view=rev
Log:
Recast "passive" profile flag in terms of browser.

Added:
    trunk/opensaml-profile-api/src/test/java/org/opensaml/profile/context/
    trunk/opensaml-profile-api/src/test/java/org/opensaml/profile/context/ProfileRequestContextTest.java   (with props)
Modified:
    trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/context/ProfileRequestContext.java

Modified: trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/context/ProfileRequestContext.java
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/context/ProfileRequestContext.java?rev=3907&r1=3906&r2=3907&view=diff
==============================================================================
--- trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/context/ProfileRequestContext.java (original)
+++ trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/context/ProfileRequestContext.java Mon Jun  2 12:57:28 2014
@@ -45,19 +45,17 @@
     /** Unique identifier for the profile/operation/function of the current request. */
     private String profileId;
 
-    /**
-     * Indicates whether the current profile request is passive. Passive requests are not capable of showing a UI to a
-     * user.
-     */
-    private boolean passiveProfile;
+    /** Whether the current profile request is browser-based. */
+    private boolean browserProfile;
 
     /** Constructor. */
     public ProfileRequestContext() {
         profileId = ANONYMOUS_PROFILE_ID;
+        browserProfile = true;
     }
 
     /**
-     * Gets the ID of the profile used by the current request.
+     * Get the ID of the profile used by the current request.
      * 
      * @return ID of the profile used by the current request
      */
@@ -66,7 +64,7 @@
     }
 
     /**
-     * Sets the ID of the profile used by the current request.
+     * Set the ID of the profile used by the current request.
      * 
      * @param id ID of the profile used by the current request
      */
@@ -80,21 +78,21 @@
     }
 
     /**
      * Gets whether the current profile request is passive.
      * 
      * @return whether the current profile request is passive
      */
-    public boolean isPassiveProfile() {
-        return passiveProfile;
+    public boolean isBrowserProfile() {
+        return browserProfile;
     }
 
     /**
      * Sets whether the current profile request is passive.
      * 
      * @param isPassive whether the current profile request is passive
      */
-    public void setPassiveProfile(final boolean isPassive) {
-        passiveProfile = isPassive;
+    public void setBrowserProfile(final boolean browser) {
+        browserProfile = browser;
     }
 
 }
@@ -80,21 +78,21 @@
 
     /**
-     * Gets whether the current profile request is passive.
+     * Get whether the current profile request is browser-based (defaults to true).
      * 
@@ -80,21 +78,21 @@
      * 
-     * @return whether the current profile request is passive
+     * @return whether the current profile request is browser-based
      */
@@ -80,21 +78,21 @@
 
     /**
-     * Sets whether the current profile request is passive.
+     * Set whether the current profile request is browser-based.
      * 
@@ -80,21 +78,21 @@
      * 
-     * @param isPassive whether the current profile request is passive
+     * @param browser whether the current profile request is browser-based
      */



More information about the commits mailing list